@@ -25,7 +25,7 @@ class AddressInfo():
         except:
             pass
 
-    def __init__(self, data_dir, address, name, connection_is_bus=True):
+    def __init__(self, data_dir, address, name, unique_name, connection_is_bus=True):
         self.data_dir = data_dir
         signal_dict = {
             'treeview_row_activated_cb': self.__treeview_row_activated_cb,
@@ -34,7 +34,8 @@ class AddressInfo():
             }
 
         self.address = address  # can be Gio.BusType.SYSTEM or Gio.BusType.SYSTEM or other address
-        self.name = name  # the bus name or None
+        self.name = name  # the well-known name or None
+        self.unique_name = unique_name  # the unique name or None
         self.connection_is_bus = connection_is_bus  # is it a bus or a p2p connection?
 
         #setup UI
@@ -241,10 +242,7 @@ class AddressInfo():
                 self.__spinner.set_visible(False)
                 #update name, unique name, ...
                 self.__label_name.set_text(self.name)
-                try:
-                    self.__label_unique_name.set_text(self.connection.get_unique_name())
-                except:
-                    pass
+                self.__label_unique_name.set_text(self.unique_name)
 
                 self.introspect_box.show_all()
 
@@ -278,7 +276,7 @@ if __name__ == "__main__":
         addr = p.addr
 
     name = p.name
-    ai = AddressInfo(addr, name, not p.p2p)
+    ai = AddressInfo(addr, name, None, not p.p2p)
     win = Gtk.Window()
     win.connect("delete-event", Gtk.main_quit)
     win.set_default_size(1024, 768)
