@@ -23,6 +23,7 @@ XML = """
     </method>
     <property name="TestString" type="s" access="readwrite"/>
     <property name="TestBool" type="b" access="read"/>
+    <property name="TestStruct" type="(suu)" access="read"/>
     <signal name="TestSignal">
       <arg name="SigString" type="s"/>
       <arg name="SigBool" type="b"/>
@@ -55,7 +56,7 @@ class IntrospectionHelperTest(unittest.TestCase):
         self.assertEqual(obj_iface.name, self.name)
         self.assertEqual(obj_iface.object_path, self.object_path)
         self.assertEqual(len(obj_iface.iface_info.methods), 1)
-        self.assertEqual(len(obj_iface.iface_info.properties), 2)
+        self.assertEqual(len(obj_iface.iface_info.properties), 3)
         self.assertEqual(len(obj_iface.iface_info.signals), 1)
 
     def test_dbus_property(self):
@@ -65,6 +66,10 @@ class IntrospectionHelperTest(unittest.TestCase):
         obj_prop = DBusProperty(obj_iface, obj_iface.iface_info.properties[0])
         self.assertEqual(obj_prop.name, self.name)
         self.assertEqual(obj_prop.object_path, self.object_path)
+        #get the markup string with value for struct prop (see bgo #702593)
+        obj_prop = DBusProperty(obj_iface, obj_iface.iface_info.properties[2])
+        obj_prop.value = ("string", 1, 2)
+        self.assertIn("'string', 1, 2", obj_prop.markup_str)
 
     def test_dbus_signal(self):
         """test DBusSignal class"""
@@ -88,7 +93,7 @@ class AddressInfoTest(unittest.TestCase):
 
     def test_bus(self):
         """introspect a name on the system bus"""
-        ai = AddressInfo(DATA_DIR, self.bus.get_bus_address(), "org.freedesktop.DBus")
+        ai = AddressInfo(DATA_DIR, self.bus.get_bus_address(), None, "org.freedesktop.DBus")
 
     @unittest.skip("TODO:peer to peer test not implemented")
     def test_peer_to_peer(self):
